# encoding: utf-8
import asyncio
import logging

import grpc
from google.protobuf import json_format

from ..kaspa_grpc import messages_pb2_grpc
from ..kaspa_grpc.messages_pb2 import KaspadRequest

MAX_MESSAGE_LENGTH = 1024 * 1024 * 1024  # 1GB

_logger = logging.getLogger(__name__)


# pipenv run python -m grpc_tools.protoc -I./protos --python_out=. --grpc_python_out=. ./protos/rpc.proto ./protos/messages.proto ./protos/p2p.proto

class KaspadStream(object):
    def __init__(self, kaspad_host: str, kaspad_port: int = 16110):

        self.__kaspad_host = kaspad_host
        self.__kaspad_port = kaspad_port

        self.__command_queue = asyncio.queues.Queue()
        self.__read_queue = asyncio.queues.Queue()

        self.__channel = grpc.aio.insecure_channel(f'{kaspad_host}:{kaspad_port}',
                                                   compression=grpc.Compression.Gzip,
                                                   options=[
                                                       ('kaspa_grpc.max_send_message_length', MAX_MESSAGE_LENGTH),
                                                       ('kaspa_grpc.max_receive_message_length', MAX_MESSAGE_LENGTH),
                                                   ])

        self.__stub = messages_pb2_grpc.RPCStub(self.__channel)
        asyncio.get_running_loop().create_task(self.__loop())

    async def read(self, wait_for_response_key=None):
        while True:
            response = await self.__read_queue.get()
            if wait_for_response_key is None or wait_for_response_key in response:
                return response

    async def send(self, command: str, params: dict = None):
        await self.__command_queue.put((command, params))

    async def __loop(self):
        async for resp in self.__stub.MessageStream(self.yield_cmd()):
            await self.__read_queue.put(msg := json_format.MessageToDict(resp, including_default_value_fields=True))
            _logger.info(f"RECV {msg}")

    async def yield_cmd(self):
        while True:
            (cmd, params) = await self.__command_queue.get()
            msg = KaspadRequest()
            msg2 = getattr(msg, cmd)
            payload = params

            if payload:
                if isinstance(payload, dict):
                    json_format.ParseDict(payload, msg2)
                if isinstance(payload, str):
                    json_format.Parse(payload, msg2)

            msg2.SetInParent()
            yield msg



# encoding: utf-8

from kaspad_client.modules.KaspadStream import KaspadStream


# pipenv run python -m grpc_tools.protoc -I./protos --python_out=. --grpc_python_out=. ./protos/rpc.proto ./protos/messages.proto ./protos/p2p.proto

class KaspadClient(object):
    def __init__(self, kaspad_host: str, kaspad_port: int = 16110):
        self.kaspad_host = kaspad_host
        self.kaspad_port = kaspad_port

        self.server_version = None
        self.is_utxo_indexed = None
        self.is_synced = None
        self.p2p_id = None

        self.kaspa_stream = KaspadStream(self.kaspad_host, self.kaspad_port)

    async def request(self, command, params=None, wait_for_response_key=None):
        await self.kaspa_stream.send(command, params)
        if wait_for_response_key:
            return await self.kaspa_stream.read(wait_for_response_key)

    # async def notify(self, command, params, callback):
    #     t = KaspadThread(self.kaspad_host, self.kaspad_port, async_thread=True)
    #     return await t.notify(command, params, callback)

    async def get_block_dag_info(self):
        """
        GetBlockDagInfoRequestMessage requests general information about the current state
        of this kaspad_client's DAG.
        :return:
        """
        return await self.request("getBlockDagInfoRequest", "", "getBlockDagInfoResponse")

    async def get_current_network(self):
        """
        GetCurrentNetworkRequestMessage requests the network kaspad_client is currently running against.

        Possible networks are: Mainnet, Testnet, Simnet, Devnet
        :return:
        """
        return await self.request("getCurrentNetworkRequest", "", "getCurrentNetworkResponse")

    async def submit_block(self, block: dict, allow_non_daa_blocks: bool):
        """
        SubmitBlockRequestMessage requests to submit a block into the DAG.
        Blocks are generally expected to have been generated using the getBlockTemplate call.

        See: GetBlockTemplateRequestMessage
        :param block:
        :param allow_non_daa_blocks:
        :return:
        """
        return await self.request("submitBlockRequest",
                                  {"block": block, "allowNonDAABlocks": allow_non_daa_blocks},
                                  "submitBlockResponse")

    async def get_block_template(self, pay_address: str, extra_data: bool):
        """
        GetBlockTemplateRequestMessage requests a current block template.
        Callers are expected to solve the block template and submit it using the submitBlock call
        :param pay_address:
        :param extra_data:
        :return:
        """
        return await self.request("getBlockTemplateRequest",
                                  {"payAddress": pay_address,
                                   "extraData": extra_data}, "getBlockTemplateResponse")

    async def get_peer_addresses(self):
        """
        GetPeerAddressesRequestMessage requests the list of known kaspad_client addresses in the
        current network. (mainnet, testnet, etc.)
        :return:
        """
        return await self.request("getPeerAddressesRequest",
                                  wait_for_response_key="getPeerAddressesResponse")

    async def get_sink(self):
        """
        GetSinkRequestMessage requests the hash of the current virtual's
        selected parent.
        :return:
        """
        return await self.request("getSinkRequest",
                                  wait_for_response_key="getSinkResponse")

    async def get_mempool_entry(self, tx_id: str, include_orphan_pool: bool, filter_transaction_pool: bool):
        """
        GetMempoolEntryRequestMessage requests information about a specific transaction
        in the mempool.
        :param tx_id:
        :param include_orphan_pool:
        :param filter_transaction_pool:
        :return:
        """
        return await self.request("getMempoolEntryRequest",
                                  {
                                      "txId": tx_id,
                                      "includeOrphanPool": include_orphan_pool,
                                      "filterTransactionPool": filter_transaction_pool
                                  },
                                  wait_for_response_key="getMempoolEntryResponse")

    async def get_mempool_entries(self, include_orphan_pool: bool, filter_transaction_pool: bool):
        """
        GetMempoolEntriesRequestMessage requests information about all the transactions
        currently in the mempool.
        :param include_orphan_pool:
        :param filter_transaction_pool:
        :return:
        """
        return await self.request("getMempoolEntriesRequest",
                                  {
                                      "includeOrphanPool": include_orphan_pool,
                                      "filterTransactionPool": filter_transaction_pool
                                  },
                                  wait_for_response_key="getMempoolEntriesResponse")

    async def get_connected_peer_info(self):
        """
        GetConnectedPeerInfoRequestMessage requests information about all the p2p peers
        currently connected to this kaspad_client.
        :return:
        """
        return await self.request("getConnectedPeerInfoRequest",
                                  wait_for_response_key="getConnectedPeerInfoResponse")

    async def add_peer(self, address: str, is_permanent: bool):
        """
        AddPeerRequestMessage adds a peer to kaspad_client's outgoing connection list.
        This will, in most cases, result in kaspad_client connecting to said peer.
        :param address:
        :param is_permanent:
        :return:
        """
        return await self.request("addPeerRequest",
                                  {
                                      "address": address,
                                      "isPermanent": is_permanent
                                  },
                                  wait_for_response_key="addPeerResponse")

    async def submit_transaction(self, transaction: dict, allow_orphan: bool = False):
        """
        SubmitTransactionRequestMessage submits a transaction to the mempool
        :param transaction:
        :param allow_orphan:
        :return:
        """
        return await self.request("submitTransactionRequest",
                                  {
                                      "transaction": transaction,
                                      "allowOrphan": allow_orphan
                                  },
                                  wait_for_response_key="submitTransactionResponse")

    async def get_block(self, hash: str, include_transactions: bool):
        """
        GetBlockRequestMessage requests information about a specific block
        :param hash:
        :param include_transactions:
        :return:
        """
        return await self.request("getBlockRequest",
                                  {
                                      "hash": hash,
                                      "includeTransactions": include_transactions,
                                  },
                                  wait_for_response_key="getBlockResponse")

    async def get_subnetwork(self, subnetwork_id: str):
        """
        GetSubnetworkRequestMessage requests information about a specific subnetwork
        :param subnetwork_id:
        :return:
        """
        return await self.request("getSubnetworkRequest",
                                  {
                                      "subnetworkId": subnetwork_id
                                  },
                                  wait_for_response_key="getSubnetworkResponse")

    async def get_virtual_chain_from_block(self, start_hash: str, include_accepted_transaction_ids: bool):
        """
        GetVirtualChainFromBlockRequestMessage requests the virtual selected
        parent chain from some startHash to this kaspad_client's current virtual
        :param start_hash:
        :param include_accepted_transaction_ids:
        :return:
        """
        return await self.request("getVirtualChainFromBlockRequest",
                                  {
                                      "startHash": start_hash,
                                      "includeAcceptedTransactionIds": include_accepted_transaction_ids
                                  },
                                  wait_for_response_key="getVirtualChainFromBlockResponse")

    async def get_blocks(self, low_hash: str, include_blocks: bool, include_transactions: bool):
        """
        GetBlocksRequestMessage requests blocks between a certain block lowHash up to this
        kaspad_client's current virtual.
        :param low_hash:
        :param include_blocks:
        :param include_transactions:
        :return:
        """
        return await self.request("getBlocksRequest",
                                  {
                                      "lowHash": low_hash,
                                      "includeBlocks": include_blocks,
                                      "includeTransactions": include_transactions

                                  },
                                  wait_for_response_key="getBlocksResponse")

    async def get_block_count(self):
        """
        GetBlockCountRequestMessage requests the current number of blocks in this kaspad_client.
        Note that this number may decrease as pruning occurs.
        :return:
        """
        return await self.request("getBlockCountRequest",
                                  wait_for_response_key="getBlockCountResponse")

    async def get_headers(self, start_hash: str, limit: int, is_ascending: bool):
        """
        GetHeadersRequestMessage requests headers between the given startHash and the
        current virtual, up to the given limit.
        :param start_hash:
        :param limit:
        :param is_ascending:
        :return:
        """
        return await self.request("getHeadersRequest",
                                  {
                                      "startHash": start_hash,
                                      "limit": limit,
                                      "isAscending": is_ascending
                                  },
                                  wait_for_response_key="getHeadersResponse")

    async def get_utxos_by_addresses(self, addresses: list[str]):
        """
        GetUtxosByAddressesRequestMessage requests all current UTXOs for the given kaspad_client addresses

        This call is only available when this kaspad_client was started with `--utxoindex`
        :param addresses:
        :return:
        """
        return await self.request("getUtxosByAddressesRequest",
                                  {
                                      "addresses": addresses
                                  },
                                  wait_for_response_key="getUtxosByAddressesResponse")

    async def get_balance_by_address(self, address: str):
        """
        GetBalanceByAddressRequest returns the total balance in unspent transactions towards a given address
        :param address:
        :return:
        """
        return await self.request("getBalanceByAddressRequest",
                                  {
                                      "address": address
                                  },
                                  wait_for_response_key="getBalanceByAddressResponse")

    async def get_balances_by_addresses(self, addresses: list[str]):
        """

        :param addresses:
        :return:
        """
        return await self.request("getBalancesByAddressesRequest",
                                  {
                                      "addresses": addresses
                                  },
                                  wait_for_response_key="getBalancesByAddressesResponse")

    async def get_sink_blue_score(self):
        """
        GetSinkBlueScoreRequestMessage requests the blue score of the current selected parent
        of the virtual block.
        :return:
        """
        return await self.request("getSinkBlueScoreRequest",
                                  wait_for_response_key="getSinkBlueScoreResponse")

    async def ban(self, ip: str):
        """
        BanRequestMessage bans the given ip.
        :param ip:
        :return:
        """
        return await self.request("banRequest",
                                  {"ip": ip},
                                  wait_for_response_key="banResponse")

    async def get_info(self):
        """
        GetInfoRequestMessage returns info about the node.
        :return:
        """
        return await self.request("getInfoRequest",
                                  wait_for_response_key="getInfoResponse")

    async def get_coin_supply(self):
        """
        Returns information about the circulating and the maximum supply.
        :return:
        """
        return await self.request("getCoinSupplyRequest",
                                  wait_for_response_key="getCoinSupplyResponse")

    async def ping(self):
        """
        Pings the node.
        :return:
        """
        return await self.request("pingRequest",
                                  wait_for_response_key="pingResponse")

    async def get_server_info(self):
        """
        Returns information about the server.
        :return:
        """
        return await self.request("getServerInfoRequest",
                                  wait_for_response_key="getServerInfoResponse")

    async def get_sync_status(self):
        """
        Returns the nodes sync status.
        :return:
        """
        return await self.request("getSyncStatusRequest",
                                  wait_for_response_key="getSyncStatusResponse")

    async def get_daa_score_timestamp_estimate(self, daa_scores: list[int]):
        """
        ???
        :param daa_scores:
        :return:
        """
        return await self.request("GetDaaScoreTimestampEstimateRequest",
                                  wait_for_response_key="GetDaaScoreTimestampEstimateResponse")

    # async def estimate_network_hashes_per_second(self, window_size: int, start_hash: str):
    #     return await self.request("EstimateNetworkHashesPerSecondRequest",
    #                               {
    #                                   "windowSize": window_size,
    #                                   "startHash": start_hash
    #                               },
    #                               wait_for_response_key="EstimateNetworkHashesPerSecondResponse")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from . import rpc_pb2 as rpc__pb2  # noqa: F401
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0emessages.proto\x12\tprotowire\x1a\trpc.proto\"\x98\x1c\n\rKaspadRequest\x12\n\n\x02id\x18\x65 \x01(\x04\x12O\n\x18getCurrentNetworkRequest\x18\xe9\x07 \x01(\x0b\x32*.protowire.GetCurrentNetworkRequestMessageH\x00\x12\x43\n\x12submitBlockRequest\x18\xeb\x07 \x01(\x0b\x32$.protowire.SubmitBlockRequestMessageH\x00\x12M\n\x17getBlockTemplateRequest\x18\xed\x07 \x01(\x0b\x32).protowire.GetBlockTemplateRequestMessageH\x00\x12M\n\x17notifyBlockAddedRequest\x18\xef\x07 \x01(\x0b\x32).protowire.NotifyBlockAddedRequestMessageH\x00\x12M\n\x17getPeerAddressesRequest\x18\xf2\x07 \x01(\x0b\x32).protowire.GetPeerAddressesRequestMessageH\x00\x12;\n\x0eGetSinkRequest\x18\xf4\x07 \x01(\x0b\x32 .protowire.GetSinkRequestMessageH\x00\x12K\n\x16getMempoolEntryRequest\x18\xf6\x07 \x01(\x0b\x32(.protowire.GetMempoolEntryRequestMessageH\x00\x12U\n\x1bgetConnectedPeerInfoRequest\x18\xf8\x07 \x01(\x0b\x32-.protowire.GetConnectedPeerInfoRequestMessageH\x00\x12;\n\x0e\x61\x64\x64PeerRequest\x18\xfa\x07 \x01(\x0b\x32 .protowire.AddPeerRequestMessageH\x00\x12O\n\x18submitTransactionRequest\x18\xfc\x07 \x01(\x0b\x32*.protowire.SubmitTransactionRequestMessageH\x00\x12_\n notifyVirtualChainChangedRequest\x18\xfe\x07 \x01(\x0b\x32\x32.protowire.NotifyVirtualChainChangedRequestMessageH\x00\x12=\n\x0fgetBlockRequest\x18\x81\x08 \x01(\x0b\x32!.protowire.GetBlockRequestMessageH\x00\x12G\n\x14getSubnetworkRequest\x18\x83\x08 \x01(\x0b\x32&.protowire.GetSubnetworkRequestMessageH\x00\x12]\n\x1fgetVirtualChainFromBlockRequest\x18\x85\x08 \x01(\x0b\x32\x31.protowire.GetVirtualChainFromBlockRequestMessageH\x00\x12?\n\x10getBlocksRequest\x18\x87\x08 \x01(\x0b\x32\".protowire.GetBlocksRequestMessageH\x00\x12G\n\x14getBlockCountRequest\x18\x89\x08 \x01(\x0b\x32&.protowire.GetBlockCountRequestMessageH\x00\x12K\n\x16getBlockDagInfoRequest\x18\x8b\x08 \x01(\x0b\x32(.protowire.GetBlockDagInfoRequestMessageH\x00\x12[\n\x1eresolveFinalityConflictRequest\x18\x8d\x08 \x01(\x0b\x32\x30.protowire.ResolveFinalityConflictRequestMessageH\x00\x12Y\n\x1dnotifyFinalityConflictRequest\x18\x8f\x08 \x01(\x0b\x32/.protowire.NotifyFinalityConflictRequestMessageH\x00\x12O\n\x18getMempoolEntriesRequest\x18\x93\x08 \x01(\x0b\x32*.protowire.GetMempoolEntriesRequestMessageH\x00\x12=\n\x0fshutdownRequest\x18\x95\x08 \x01(\x0b\x32!.protowire.ShutdownRequestMessageH\x00\x12\x41\n\x11getHeadersRequest\x18\x97\x08 \x01(\x0b\x32#.protowire.GetHeadersRequestMessageH\x00\x12Q\n\x19notifyUtxosChangedRequest\x18\x99\x08 \x01(\x0b\x32+.protowire.NotifyUtxosChangedRequestMessageH\x00\x12S\n\x1agetUtxosByAddressesRequest\x18\x9c\x08 \x01(\x0b\x32,.protowire.GetUtxosByAddressesRequestMessageH\x00\x12M\n\x17getSinkBlueScoreRequest\x18\x9e\x08 \x01(\x0b\x32).protowire.GetSinkBlueScoreRequestMessageH\x00\x12\x61\n!notifySinkBlueScoreChangedRequest\x18\xa0\x08 \x01(\x0b\x32\x33.protowire.NotifySinkBlueScoreChangedRequestMessageH\x00\x12\x33\n\nbanRequest\x18\xa3\x08 \x01(\x0b\x32\x1c.protowire.BanRequestMessageH\x00\x12\x37\n\x0cunbanRequest\x18\xa5\x08 \x01(\x0b\x32\x1e.protowire.UnbanRequestMessageH\x00\x12;\n\x0egetInfoRequest\x18\xa7\x08 \x01(\x0b\x32 .protowire.GetInfoRequestMessageH\x00\x12_\n stopNotifyingUtxosChangedRequest\x18\xa9\x08 \x01(\x0b\x32\x32.protowire.StopNotifyingUtxosChangedRequestMessageH\x00\x12o\n(notifyPruningPointUtxoSetOverrideRequest\x18\xab\x08 \x01(\x0b\x32:.protowire.NotifyPruningPointUtxoSetOverrideRequestMessageH\x00\x12}\n/stopNotifyingPruningPointUtxoSetOverrideRequest\x18\xae\x08 \x01(\x0b\x32\x41.protowire.StopNotifyingPruningPointUtxoSetOverrideRequestMessageH\x00\x12i\n%estimateNetworkHashesPerSecondRequest\x18\xb0\x08 \x01(\x0b\x32\x37.protowire.EstimateNetworkHashesPerSecondRequestMessageH\x00\x12\x65\n#notifyVirtualDaaScoreChangedRequest\x18\xb2\x08 \x01(\x0b\x32\x35.protowire.NotifyVirtualDaaScoreChangedRequestMessageH\x00\x12S\n\x1agetBalanceByAddressRequest\x18\xb5\x08 \x01(\x0b\x32,.protowire.GetBalanceByAddressRequestMessageH\x00\x12Y\n\x1dgetBalancesByAddressesRequest\x18\xb7\x08 \x01(\x0b\x32/.protowire.GetBalancesByAddressesRequestMessageH\x00\x12Y\n\x1dnotifyNewBlockTemplateRequest\x18\xb9\x08 \x01(\x0b\x32/.protowire.NotifyNewBlockTemplateRequestMessageH\x00\x12\x65\n#getMempoolEntriesByAddressesRequest\x18\xbc\x08 \x01(\x0b\x32\x35.protowire.GetMempoolEntriesByAddressesRequestMessageH\x00\x12G\n\x14getCoinSupplyRequest\x18\xbe\x08 \x01(\x0b\x32&.protowire.GetCoinSupplyRequestMessageH\x00\x12\x35\n\x0bpingRequest\x18\xc0\x08 \x01(\x0b\x32\x1d.protowire.PingRequestMessageH\x00\x12\x41\n\x11getMetricsRequest\x18\xc2\x08 \x01(\x0b\x32#.protowire.GetMetricsRequestMessageH\x00\x12G\n\x14getServerInfoRequest\x18\xc4\x08 \x01(\x0b\x32&.protowire.GetServerInfoRequestMessageH\x00\x12G\n\x14getSyncStatusRequest\x18\xc6\x08 \x01(\x0b\x32&.protowire.GetSyncStatusRequestMessageH\x00\x12\x65\n#GetDaaScoreTimestampEstimateRequest\x18\xc8\x08 \x01(\x0b\x32\x35.protowire.GetDaaScoreTimestampEstimateRequestMessageH\x00\x42\t\n\x07payload\"\xbe#\n\x0eKaspadResponse\x12\n\n\x02id\x18\x65 \x01(\x04\x12Q\n\x19getCurrentNetworkResponse\x18\xea\x07 \x01(\x0b\x32+.protowire.GetCurrentNetworkResponseMessageH\x00\x12\x45\n\x13submitBlockResponse\x18\xec\x07 \x01(\x0b\x32%.protowire.SubmitBlockResponseMessageH\x00\x12O\n\x18getBlockTemplateResponse\x18\xee\x07 \x01(\x0b\x32*.protowire.GetBlockTemplateResponseMessageH\x00\x12O\n\x18notifyBlockAddedResponse\x18\xf0\x07 \x01(\x0b\x32*.protowire.NotifyBlockAddedResponseMessageH\x00\x12K\n\x16\x62lockAddedNotification\x18\xf1\x07 \x01(\x0b\x32(.protowire.BlockAddedNotificationMessageH\x00\x12O\n\x18getPeerAddressesResponse\x18\xf3\x07 \x01(\x0b\x32*.protowire.GetPeerAddressesResponseMessageH\x00\x12=\n\x0fGetSinkResponse\x18\xf5\x07 \x01(\x0b\x32!.protowire.GetSinkResponseMessageH\x00\x12M\n\x17getMempoolEntryResponse\x18\xf7\x07 \x01(\x0b\x32).protowire.GetMempoolEntryResponseMessageH\x00\x12W\n\x1cgetConnectedPeerInfoResponse\x18\xf9\x07 \x01(\x0b\x32..protowire.GetConnectedPeerInfoResponseMessageH\x00\x12=\n\x0f\x61\x64\x64PeerResponse\x18\xfb\x07 \x01(\x0b\x32!.protowire.AddPeerResponseMessageH\x00\x12Q\n\x19submitTransactionResponse\x18\xfd\x07 \x01(\x0b\x32+.protowire.SubmitTransactionResponseMessageH\x00\x12\x61\n!notifyVirtualChainChangedResponse\x18\xff\x07 \x01(\x0b\x32\x33.protowire.NotifyVirtualChainChangedResponseMessageH\x00\x12]\n\x1fvirtualChainChangedNotification\x18\x80\x08 \x01(\x0b\x32\x31.protowire.VirtualChainChangedNotificationMessageH\x00\x12?\n\x10getBlockResponse\x18\x82\x08 \x01(\x0b\x32\".protowire.GetBlockResponseMessageH\x00\x12I\n\x15getSubnetworkResponse\x18\x84\x08 \x01(\x0b\x32\'.protowire.GetSubnetworkResponseMessageH\x00\x12_\n getVirtualChainFromBlockResponse\x18\x86\x08 \x01(\x0b\x32\x32.protowire.GetVirtualChainFromBlockResponseMessageH\x00\x12\x41\n\x11getBlocksResponse\x18\x88\x08 \x01(\x0b\x32#.protowire.GetBlocksResponseMessageH\x00\x12I\n\x15getBlockCountResponse\x18\x8a\x08 \x01(\x0b\x32\'.protowire.GetBlockCountResponseMessageH\x00\x12M\n\x17getBlockDagInfoResponse\x18\x8c\x08 \x01(\x0b\x32).protowire.GetBlockDagInfoResponseMessageH\x00\x12]\n\x1fresolveFinalityConflictResponse\x18\x8e\x08 \x01(\x0b\x32\x31.protowire.ResolveFinalityConflictResponseMessageH\x00\x12[\n\x1enotifyFinalityConflictResponse\x18\x90\x08 \x01(\x0b\x32\x30.protowire.NotifyFinalityConflictResponseMessageH\x00\x12W\n\x1c\x66inalityConflictNotification\x18\x91\x08 \x01(\x0b\x32..protowire.FinalityConflictNotificationMessageH\x00\x12g\n$finalityConflictResolvedNotification\x18\x92\x08 \x01(\x0b\x32\x36.protowire.FinalityConflictResolvedNotificationMessageH\x00\x12Q\n\x19getMempoolEntriesResponse\x18\x94\x08 \x01(\x0b\x32+.protowire.GetMempoolEntriesResponseMessageH\x00\x12?\n\x10shutdownResponse\x18\x96\x08 \x01(\x0b\x32\".protowire.ShutdownResponseMessageH\x00\x12\x43\n\x12getHeadersResponse\x18\x98\x08 \x01(\x0b\x32$.protowire.GetHeadersResponseMessageH\x00\x12S\n\x1anotifyUtxosChangedResponse\x18\x9a\x08 \x01(\x0b\x32,.protowire.NotifyUtxosChangedResponseMessageH\x00\x12O\n\x18utxosChangedNotification\x18\x9b\x08 \x01(\x0b\x32*.protowire.UtxosChangedNotificationMessageH\x00\x12U\n\x1bgetUtxosByAddressesResponse\x18\x9d\x08 \x01(\x0b\x32-.protowire.GetUtxosByAddressesResponseMessageH\x00\x12O\n\x18getSinkBlueScoreResponse\x18\x9f\x08 \x01(\x0b\x32*.protowire.GetSinkBlueScoreResponseMessageH\x00\x12\x63\n\"notifySinkBlueScoreChangedResponse\x18\xa1\x08 \x01(\x0b\x32\x34.protowire.NotifySinkBlueScoreChangedResponseMessageH\x00\x12_\n sinkBlueScoreChangedNotification\x18\xa2\x08 \x01(\x0b\x32\x32.protowire.SinkBlueScoreChangedNotificationMessageH\x00\x12\x35\n\x0b\x62\x61nResponse\x18\xa4\x08 \x01(\x0b\x32\x1d.protowire.BanResponseMessageH\x00\x12\x39\n\runbanResponse\x18\xa6\x08 \x01(\x0b\x32\x1f.protowire.UnbanResponseMessageH\x00\x12=\n\x0fgetInfoResponse\x18\xa8\x08 \x01(\x0b\x32!.protowire.GetInfoResponseMessageH\x00\x12\x61\n!stopNotifyingUtxosChangedResponse\x18\xaa\x08 \x01(\x0b\x32\x33.protowire.StopNotifyingUtxosChangedResponseMessageH\x00\x12q\n)notifyPruningPointUtxoSetOverrideResponse\x18\xac\x08 \x01(\x0b\x32;.protowire.NotifyPruningPointUtxoSetOverrideResponseMessageH\x00\x12m\n\'pruningPointUtxoSetOverrideNotification\x18\xad\x08 \x01(\x0b\x32\x39.protowire.PruningPointUtxoSetOverrideNotificationMessageH\x00\x12\x7f\n0stopNotifyingPruningPointUtxoSetOverrideResponse\x18\xaf\x08 \x01(\x0b\x32\x42.protowire.StopNotifyingPruningPointUtxoSetOverrideResponseMessageH\x00\x12k\n&estimateNetworkHashesPerSecondResponse\x18\xb1\x08 \x01(\x0b\x32\x38.protowire.EstimateNetworkHashesPerSecondResponseMessageH\x00\x12g\n$notifyVirtualDaaScoreChangedResponse\x18\xb3\x08 \x01(\x0b\x32\x36.protowire.NotifyVirtualDaaScoreChangedResponseMessageH\x00\x12\x63\n\"virtualDaaScoreChangedNotification\x18\xb4\x08 \x01(\x0b\x32\x34.protowire.VirtualDaaScoreChangedNotificationMessageH\x00\x12U\n\x1bgetBalanceByAddressResponse\x18\xb6\x08 \x01(\x0b\x32-.protowire.GetBalanceByAddressResponseMessageH\x00\x12[\n\x1egetBalancesByAddressesResponse\x18\xb8\x08 \x01(\x0b\x32\x30.protowire.GetBalancesByAddressesResponseMessageH\x00\x12[\n\x1enotifyNewBlockTemplateResponse\x18\xba\x08 \x01(\x0b\x32\x30.protowire.NotifyNewBlockTemplateResponseMessageH\x00\x12W\n\x1cnewBlockTemplateNotification\x18\xbb\x08 \x01(\x0b\x32..protowire.NewBlockTemplateNotificationMessageH\x00\x12g\n$getMempoolEntriesByAddressesResponse\x18\xbd\x08 \x01(\x0b\x32\x36.protowire.GetMempoolEntriesByAddressesResponseMessageH\x00\x12I\n\x15getCoinSupplyResponse\x18\xbf\x08 \x01(\x0b\x32\'.protowire.GetCoinSupplyResponseMessageH\x00\x12\x37\n\x0cpingResponse\x18\xc1\x08 \x01(\x0b\x32\x1e.protowire.PingResponseMessageH\x00\x12\x43\n\x12getMetricsResponse\x18\xc3\x08 \x01(\x0b\x32$.protowire.GetMetricsResponseMessageH\x00\x12I\n\x15getServerInfoResponse\x18\xc5\x08 \x01(\x0b\x32\'.protowire.GetServerInfoResponseMessageH\x00\x12I\n\x15getSyncStatusResponse\x18\xc7\x08 \x01(\x0b\x32\'.protowire.GetSyncStatusResponseMessageH\x00\x12g\n$GetDaaScoreTimestampEstimateResponse\x18\xc9\x08 \x01(\x0b\x32\x36.protowire.GetDaaScoreTimestampEstimateResponseMessageH\x00\x42\t\n\x07payload2Q\n\x03RPC\x12J\n\rMessageStream\x12\x18.protowire.KaspadRequest\x1a\x19.protowire.KaspadResponse\"\x00(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._options = None
    _globals['_KASPADREQUEST']._serialized_start = 41
    _globals['_KASPADREQUEST']._serialized_end = 3649
    _globals['_KASPADRESPONSE']._serialized_start = 3652
    _globals['_KASPADRESPONSE']._serialized_end = 8194
    _globals['_RPC']._serialized_start = 8196
    _globals['_RPC']._serialized_end = 8277
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\trpc.proto\x12\tprotowire\"\x1b\n\x08RPCError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x9b\x01\n\x08RpcBlock\x12)\n\x06header\x18\x01 \x01(\x0b\x32\x19.protowire.RpcBlockHeader\x12/\n\x0ctransactions\x18\x02 \x03(\x0b\x32\x19.protowire.RpcTransaction\x12\x33\n\x0bverboseData\x18\x03 \x01(\x0b\x32\x1e.protowire.RpcBlockVerboseData\"\x9e\x02\n\x0eRpcBlockHeader\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x30\n\x07parents\x18\x0c \x03(\x0b\x32\x1f.protowire.RpcBlockLevelParents\x12\x16\n\x0ehashMerkleRoot\x18\x03 \x01(\t\x12\x1c\n\x14\x61\x63\x63\x65ptedIdMerkleRoot\x18\x04 \x01(\t\x12\x16\n\x0eutxoCommitment\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x03\x12\x0c\n\x04\x62its\x18\x07 \x01(\r\x12\r\n\x05nonce\x18\x08 \x01(\x04\x12\x10\n\x08\x64\x61\x61Score\x18\t \x01(\x04\x12\x10\n\x08\x62lueWork\x18\n \x01(\t\x12\x14\n\x0cpruningPoint\x18\x0e \x01(\t\x12\x11\n\tblueScore\x18\r \x01(\x04\",\n\x14RpcBlockLevelParents\x12\x14\n\x0cparentHashes\x18\x01 \x03(\t\"\xfb\x01\n\x13RpcBlockVerboseData\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x12\n\ndifficulty\x18\x0b \x01(\x01\x12\x1a\n\x12selectedParentHash\x18\r \x01(\t\x12\x16\n\x0etransactionIds\x18\x0e \x03(\t\x12\x14\n\x0cisHeaderOnly\x18\x0f \x01(\x08\x12\x11\n\tblueScore\x18\x10 \x01(\x04\x12\x16\n\x0e\x63hildrenHashes\x18\x11 \x03(\t\x12\x1b\n\x13mergeSetBluesHashes\x18\x12 \x03(\t\x12\x1a\n\x12mergeSetRedsHashes\x18\x13 \x03(\t\x12\x14\n\x0cisChainBlock\x18\x14 \x01(\x08\"\x92\x02\n\x0eRpcTransaction\x12\x0f\n\x07version\x18\x01 \x01(\r\x12.\n\x06inputs\x18\x02 \x03(\x0b\x32\x1e.protowire.RpcTransactionInput\x12\x30\n\x07outputs\x18\x03 \x03(\x0b\x32\x1f.protowire.RpcTransactionOutput\x12\x10\n\x08lockTime\x18\x04 \x01(\x04\x12\x14\n\x0csubnetworkId\x18\x05 \x01(\t\x12\x0b\n\x03gas\x18\x06 \x01(\x04\x12\x0f\n\x07payload\x18\x08 \x01(\t\x12\x39\n\x0bverboseData\x18\t \x01(\x0b\x32$.protowire.RpcTransactionVerboseData\x12\x0c\n\x04mass\x18\n \x01(\x04\"\xc6\x01\n\x13RpcTransactionInput\x12\x30\n\x10previousOutpoint\x18\x01 \x01(\x0b\x32\x16.protowire.RpcOutpoint\x12\x17\n\x0fsignatureScript\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x12\n\nsigOpCount\x18\x05 \x01(\r\x12>\n\x0bverboseData\x18\x04 \x01(\x0b\x32).protowire.RpcTransactionInputVerboseData\">\n\x12RpcScriptPublicKey\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x17\n\x0fscriptPublicKey\x18\x02 \x01(\t\"\x9f\x01\n\x14RpcTransactionOutput\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x04\x12\x36\n\x0fscriptPublicKey\x18\x02 \x01(\x0b\x32\x1d.protowire.RpcScriptPublicKey\x12?\n\x0bverboseData\x18\x03 \x01(\x0b\x32*.protowire.RpcTransactionOutputVerboseData\"3\n\x0bRpcOutpoint\x12\x15\n\rtransactionId\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\"\x81\x01\n\x0cRpcUtxoEntry\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x04\x12\x36\n\x0fscriptPublicKey\x18\x02 \x01(\x0b\x32\x1d.protowire.RpcScriptPublicKey\x12\x15\n\rblockDaaScore\x18\x03 \x01(\x04\x12\x12\n\nisCoinbase\x18\x04 \x01(\x08\"t\n\x19RpcTransactionVerboseData\x12\x15\n\rtransactionId\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x0c\n\x04mass\x18\x04 \x01(\x04\x12\x11\n\tblockHash\x18\x0c \x01(\t\x12\x11\n\tblockTime\x18\x0e \x01(\x04\" \n\x1eRpcTransactionInputVerboseData\"^\n\x1fRpcTransactionOutputVerboseData\x12\x1b\n\x13scriptPublicKeyType\x18\x05 \x01(\t\x12\x1e\n\x16scriptPublicKeyAddress\x18\x06 \x01(\t\"!\n\x1fGetCurrentNetworkRequestMessage\"_\n GetCurrentNetworkResponseMessage\x12\x16\n\x0e\x63urrentNetwork\x18\x01 \x01(\t\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"Z\n\x19SubmitBlockRequestMessage\x12\"\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x13.protowire.RpcBlock\x12\x19\n\x11\x61llowNonDAABlocks\x18\x03 \x01(\x08\"\xc7\x01\n\x1aSubmitBlockResponseMessage\x12H\n\x0crejectReason\x18\x01 \x01(\x0e\x32\x32.protowire.SubmitBlockResponseMessage.RejectReason\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\":\n\x0cRejectReason\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rBLOCK_INVALID\x10\x01\x12\r\n\tIS_IN_IBD\x10\x02\"G\n\x1eGetBlockTemplateRequestMessage\x12\x12\n\npayAddress\x18\x01 \x01(\t\x12\x11\n\textraData\x18\x02 \x01(\t\"|\n\x1fGetBlockTemplateResponseMessage\x12\"\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x13.protowire.RpcBlock\x12\x10\n\x08isSynced\x18\x02 \x01(\x08\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"N\n\x1eNotifyBlockAddedRequestMessage\x12,\n\x07\x63ommand\x18\x65 \x01(\x0e\x32\x1b.protowire.RpcNotifyCommand\"F\n\x1fNotifyBlockAddedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"C\n\x1d\x42lockAddedNotificationMessage\x12\"\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x13.protowire.RpcBlock\" \n\x1eGetPeerAddressesRequestMessage\"\xd2\x01\n\x1fGetPeerAddressesResponseMessage\x12\x41\n\taddresses\x18\x01 \x03(\x0b\x32..protowire.GetPeerAddressesKnownAddressMessage\x12G\n\x0f\x62\x61nnedAddresses\x18\x02 \x03(\x0b\x32..protowire.GetPeerAddressesKnownAddressMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"3\n#GetPeerAddressesKnownAddressMessage\x12\x0c\n\x04\x41\x64\x64r\x18\x01 \x01(\t\"\x17\n\x15GetSinkRequestMessage\"K\n\x16GetSinkResponseMessage\x12\x0c\n\x04sink\x18\x01 \x01(\t\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"g\n\x1dGetMempoolEntryRequestMessage\x12\x0c\n\x04txId\x18\x01 \x01(\t\x12\x19\n\x11includeOrphanPool\x18\x02 \x01(\x08\x12\x1d\n\x15\x66ilterTransactionPool\x18\x03 \x01(\x08\"p\n\x1eGetMempoolEntryResponseMessage\x12)\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x1a.protowire.RpcMempoolEntry\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"[\n\x1fGetMempoolEntriesRequestMessage\x12\x19\n\x11includeOrphanPool\x18\x01 \x01(\x08\x12\x1d\n\x15\x66ilterTransactionPool\x18\x02 \x01(\x08\"t\n GetMempoolEntriesResponseMessage\x12+\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1a.protowire.RpcMempoolEntry\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"`\n\x0fRpcMempoolEntry\x12\x0b\n\x03\x66\x65\x65\x18\x01 \x01(\x04\x12.\n\x0btransaction\x18\x03 \x01(\x0b\x32\x19.protowire.RpcTransaction\x12\x10\n\x08isOrphan\x18\x04 \x01(\x08\"$\n\"GetConnectedPeerInfoRequestMessage\"\x81\x01\n#GetConnectedPeerInfoResponseMessage\x12\x35\n\x05infos\x18\x01 \x03(\x0b\x32&.protowire.GetConnectedPeerInfoMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\xdc\x01\n\x1bGetConnectedPeerInfoMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x18\n\x10lastPingDuration\x18\x03 \x01(\x03\x12\x12\n\nisOutbound\x18\x06 \x01(\x08\x12\x12\n\ntimeOffset\x18\x07 \x01(\x03\x12\x11\n\tuserAgent\x18\x08 \x01(\t\x12!\n\x19\x61\x64vertisedProtocolVersion\x18\t \x01(\r\x12\x15\n\rtimeConnected\x18\n \x01(\x03\x12\x11\n\tisIbdPeer\x18\x0b \x01(\x08\"=\n\x15\x41\x64\x64PeerRequestMessage\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x0bisPermanent\x18\x02 \x01(\x08\"=\n\x16\x41\x64\x64PeerResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"f\n\x1fSubmitTransactionRequestMessage\x12.\n\x0btransaction\x18\x01 \x01(\x0b\x32\x19.protowire.RpcTransaction\x12\x13\n\x0b\x61llowOrphan\x18\x02 \x01(\x08\"^\n SubmitTransactionResponseMessage\x12\x15\n\rtransactionId\x18\x01 \x01(\t\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"~\n\'NotifyVirtualChainChangedRequestMessage\x12%\n\x1dincludeAcceptedTransactionIds\x18\x01 \x01(\x08\x12,\n\x07\x63ommand\x18\x65 \x01(\x0e\x32\x1b.protowire.RpcNotifyCommand\"O\n(NotifyVirtualChainChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\xae\x01\n&VirtualChainChangedNotificationMessage\x12\x1f\n\x17removedChainBlockHashes\x18\x01 \x03(\t\x12\x1d\n\x15\x61\x64\x64\x65\x64\x43hainBlockHashes\x18\x03 \x03(\t\x12\x44\n\x16\x61\x63\x63\x65ptedTransactionIds\x18\x02 \x03(\x0b\x32$.protowire.RpcAcceptedTransactionIds\"C\n\x16GetBlockRequestMessage\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x1b\n\x13includeTransactions\x18\x03 \x01(\x08\"b\n\x17GetBlockResponseMessage\x12\"\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x13.protowire.RpcBlock\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"3\n\x1bGetSubnetworkRequestMessage\x12\x14\n\x0csubnetworkId\x18\x01 \x01(\t\"U\n\x1cGetSubnetworkResponseMessage\x12\x10\n\x08gasLimit\x18\x01 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"b\n&GetVirtualChainFromBlockRequestMessage\x12\x11\n\tstartHash\x18\x01 \x01(\t\x12%\n\x1dincludeAcceptedTransactionIds\x18\x02 \x01(\x08\"W\n\x19RpcAcceptedTransactionIds\x12\x1a\n\x12\x61\x63\x63\x65ptingBlockHash\x18\x01 \x01(\t\x12\x1e\n\x16\x61\x63\x63\x65ptedTransactionIds\x18\x02 \x03(\t\"\xd4\x01\n\'GetVirtualChainFromBlockResponseMessage\x12\x1f\n\x17removedChainBlockHashes\x18\x01 \x03(\t\x12\x1d\n\x15\x61\x64\x64\x65\x64\x43hainBlockHashes\x18\x03 \x03(\t\x12\x44\n\x16\x61\x63\x63\x65ptedTransactionIds\x18\x02 \x03(\x0b\x32$.protowire.RpcAcceptedTransactionIds\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"^\n\x17GetBlocksRequestMessage\x12\x0f\n\x07lowHash\x18\x01 \x01(\t\x12\x15\n\rincludeBlocks\x18\x02 \x01(\x08\x12\x1b\n\x13includeTransactions\x18\x03 \x01(\x08\"y\n\x18GetBlocksResponseMessage\x12\x13\n\x0b\x62lockHashes\x18\x04 \x03(\t\x12#\n\x06\x62locks\x18\x03 \x03(\x0b\x32\x13.protowire.RpcBlock\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1d\n\x1bGetBlockCountRequestMessage\"l\n\x1cGetBlockCountResponseMessage\x12\x12\n\nblockCount\x18\x01 \x01(\x04\x12\x13\n\x0bheaderCount\x18\x02 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1f\n\x1dGetBlockDagInfoRequestMessage\"\xa0\x02\n\x1eGetBlockDagInfoResponseMessage\x12\x13\n\x0bnetworkName\x18\x01 \x01(\t\x12\x12\n\nblockCount\x18\x02 \x01(\x04\x12\x13\n\x0bheaderCount\x18\x03 \x01(\x04\x12\x11\n\ttipHashes\x18\x04 \x03(\t\x12\x12\n\ndifficulty\x18\x05 \x01(\x01\x12\x16\n\x0epastMedianTime\x18\x06 \x01(\x03\x12\x1b\n\x13virtualParentHashes\x18\x07 \x03(\t\x12\x18\n\x10pruningPointHash\x18\x08 \x01(\t\x12\x17\n\x0fvirtualDaaScore\x18\t \x01(\x04\x12\x0c\n\x04sink\x18\n \x01(\t\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"B\n%ResolveFinalityConflictRequestMessage\x12\x19\n\x11\x66inalityBlockHash\x18\x01 \x01(\t\"M\n&ResolveFinalityConflictResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"T\n$NotifyFinalityConflictRequestMessage\x12,\n\x07\x63ommand\x18\x65 \x01(\x0e\x32\x1b.protowire.RpcNotifyCommand\"L\n%NotifyFinalityConflictResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"A\n#FinalityConflictNotificationMessage\x12\x1a\n\x12violatingBlockHash\x18\x01 \x01(\t\"H\n+FinalityConflictResolvedNotificationMessage\x12\x19\n\x11\x66inalityBlockHash\x18\x01 \x01(\t\"\x18\n\x16ShutdownRequestMessage\">\n\x17ShutdownResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"Q\n\x18GetHeadersRequestMessage\x12\x11\n\tstartHash\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x13\n\x0bisAscending\x18\x03 \x01(\x08\"Q\n\x19GetHeadersResponseMessage\x12\x0f\n\x07headers\x18\x01 \x03(\t\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"c\n NotifyUtxosChangedRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\x12,\n\x07\x63ommand\x18\x65 \x01(\x0e\x32\x1b.protowire.RpcNotifyCommand\"H\n!NotifyUtxosChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x8b\x01\n\x1fUtxosChangedNotificationMessage\x12\x32\n\x05\x61\x64\x64\x65\x64\x18\x01 \x03(\x0b\x32#.protowire.RpcUtxosByAddressesEntry\x12\x34\n\x07removed\x18\x02 \x03(\x0b\x32#.protowire.RpcUtxosByAddressesEntry\"\x81\x01\n\x18RpcUtxosByAddressesEntry\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12(\n\x08outpoint\x18\x02 \x01(\x0b\x32\x16.protowire.RpcOutpoint\x12*\n\tutxoEntry\x18\x03 \x01(\x0b\x32\x17.protowire.RpcUtxoEntry\"<\n\'StopNotifyingUtxosChangedRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\"O\n(StopNotifyingUtxosChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"6\n!GetUtxosByAddressesRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\"\x7f\n\"GetUtxosByAddressesResponseMessage\x12\x34\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.protowire.RpcUtxosByAddressesEntry\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"4\n!GetBalanceByAddressRequestMessage\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"Z\n\"GetBalanceByAddressResponseMessage\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"9\n$GetBalancesByAddressesRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\"d\n\x1bRpcBalancesByAddressesEntry\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x85\x01\n%GetBalancesByAddressesResponseMessage\x12\x37\n\x07\x65ntries\x18\x01 \x03(\x0b\x32&.protowire.RpcBalancesByAddressesEntry\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\" \n\x1eGetSinkBlueScoreRequestMessage\"Y\n\x1fGetSinkBlueScoreResponseMessage\x12\x11\n\tblueScore\x18\x01 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"X\n(NotifySinkBlueScoreChangedRequestMessage\x12,\n\x07\x63ommand\x18\x65 \x01(\x0e\x32\x1b.protowire.RpcNotifyCommand\"P\n)NotifySinkBlueScoreChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"@\n\'SinkBlueScoreChangedNotificationMessage\x12\x15\n\rsinkBlueScore\x18\x01 \x01(\x04\"Z\n*NotifyVirtualDaaScoreChangedRequestMessage\x12,\n\x07\x63ommand\x18\x65 \x01(\x0e\x32\x1b.protowire.RpcNotifyCommand\"R\n+NotifyVirtualDaaScoreChangedResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"D\n)VirtualDaaScoreChangedNotificationMessage\x12\x17\n\x0fvirtualDaaScore\x18\x01 \x01(\x04\"_\n/NotifyPruningPointUtxoSetOverrideRequestMessage\x12,\n\x07\x63ommand\x18\x65 \x01(\x0e\x32\x1b.protowire.RpcNotifyCommand\"W\n0NotifyPruningPointUtxoSetOverrideResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"0\n.PruningPointUtxoSetOverrideNotificationMessage\"8\n6StopNotifyingPruningPointUtxoSetOverrideRequestMessage\"^\n7StopNotifyingPruningPointUtxoSetOverrideResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1f\n\x11\x42\x61nRequestMessage\x12\n\n\x02ip\x18\x01 \x01(\t\"9\n\x12\x42\x61nResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"!\n\x13UnbanRequestMessage\x12\n\n\x02ip\x18\x01 \x01(\t\";\n\x14UnbanResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x17\n\x15GetInfoRequestMessage\"\xd1\x01\n\x16GetInfoResponseMessage\x12\r\n\x05p2pId\x18\x01 \x01(\t\x12\x13\n\x0bmempoolSize\x18\x02 \x01(\x04\x12\x15\n\rserverVersion\x18\x03 \x01(\t\x12\x15\n\risUtxoIndexed\x18\x04 \x01(\x08\x12\x10\n\x08isSynced\x18\x05 \x01(\x08\x12\x18\n\x10hasNotifyCommand\x18\x0b \x01(\x08\x12\x14\n\x0chasMessageId\x18\x0c \x01(\x08\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"U\n,EstimateNetworkHashesPerSecondRequestMessage\x12\x12\n\nwindowSize\x18\x01 \x01(\r\x12\x11\n\tstartHash\x18\x02 \x01(\t\"t\n-EstimateNetworkHashesPerSecondResponseMessage\x12\x1e\n\x16networkHashesPerSecond\x18\x01 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"T\n$NotifyNewBlockTemplateRequestMessage\x12,\n\x07\x63ommand\x18\x65 \x01(\x0e\x32\x1b.protowire.RpcNotifyCommand\"L\n%NotifyNewBlockTemplateResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"%\n#NewBlockTemplateNotificationMessage\"\x87\x01\n\x18RpcMempoolEntryByAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12+\n\x07sending\x18\x02 \x03(\x0b\x32\x1a.protowire.RpcMempoolEntry\x12-\n\treceiving\x18\x03 \x03(\x0b\x32\x1a.protowire.RpcMempoolEntry\"y\n*GetMempoolEntriesByAddressesRequestMessage\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x19\n\x11includeOrphanPool\x18\x02 \x01(\x08\x12\x1d\n\x15\x66ilterTransactionPool\x18\x03 \x01(\x08\"\x88\x01\n+GetMempoolEntriesByAddressesResponseMessage\x12\x34\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.protowire.RpcMempoolEntryByAddress\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1d\n\x1bGetCoinSupplyRequestMessage\"o\n\x1cGetCoinSupplyResponseMessage\x12\x10\n\x08maxSompi\x18\x01 \x01(\x04\x12\x18\n\x10\x63irculatingSompi\x18\x02 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x14\n\x12PingRequestMessage\":\n\x13PingResponseMessage\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\xde\x01\n\x0eProcessMetrics\x12\x17\n\x0fresidentSetSize\x18\x01 \x01(\x04\x12\x19\n\x11virtualMemorySize\x18\x02 \x01(\x04\x12\x0f\n\x07\x63oreNum\x18\x03 \x01(\r\x12\x10\n\x08\x63puUsage\x18\x04 \x01(\x02\x12\r\n\x05\x66\x64Num\x18\x05 \x01(\r\x12\x17\n\x0f\x64iskIoReadBytes\x18\x06 \x01(\x04\x12\x18\n\x10\x64iskIoWriteBytes\x18\x07 \x01(\x04\x12\x18\n\x10\x64iskIoReadPerSec\x18\x08 \x01(\x02\x12\x19\n\x11\x64iskIoWritePerSec\x18\t \x01(\x02\"\xe3\x01\n\x11\x43onnectionMetrics\x12\x1c\n\x14\x62orshLiveConnections\x18\x1f \x01(\r\x12\x1f\n\x17\x62orshConnectionAttempts\x18  \x01(\x04\x12\x1e\n\x16\x62orshHandshakeFailures\x18! \x01(\x04\x12\x1b\n\x13jsonLiveConnections\x18) \x01(\r\x12\x1e\n\x16jsonConnectionAttempts\x18* \x01(\x04\x12\x1d\n\x15jsonHandshakeFailures\x18+ \x01(\x04\x12\x13\n\x0b\x61\x63tivePeers\x18\x33 \x01(\r\"\xca\x01\n\x10\x42\x61ndwidthMetrics\x12\x14\n\x0c\x62orshBytesTx\x18= \x01(\x04\x12\x14\n\x0c\x62orshBytesRx\x18> \x01(\x04\x12\x13\n\x0bjsonBytesTx\x18? \x01(\x04\x12\x13\n\x0bjsonBytesRx\x18@ \x01(\x04\x12\x16\n\x0egrpcP2pBytesTx\x18\x41 \x01(\x04\x12\x16\n\x0egrpcP2pBytesRx\x18\x42 \x01(\x04\x12\x17\n\x0fgrpcUserBytesTx\x18\x43 \x01(\x04\x12\x17\n\x0fgrpcUserBytesRx\x18\x44 \x01(\x04\"\xe6\x02\n\x10\x43onsensusMetrics\x12\x17\n\x0f\x62locksSubmitted\x18\x01 \x01(\x04\x12\x14\n\x0cheaderCounts\x18\x02 \x01(\x04\x12\x11\n\tdepCounts\x18\x03 \x01(\x04\x12\x12\n\nbodyCounts\x18\x04 \x01(\x04\x12\x11\n\ttxsCounts\x18\x05 \x01(\x04\x12\x18\n\x10\x63hainBlockCounts\x18\x06 \x01(\x04\x12\x12\n\nmassCounts\x18\x07 \x01(\x04\x12\x12\n\nblockCount\x18\x0b \x01(\x04\x12\x13\n\x0bheaderCount\x18\x0c \x01(\x04\x12\x13\n\x0bmempoolSize\x18\r \x01(\x04\x12\x16\n\x0etipHashesCount\x18\x0e \x01(\r\x12\x12\n\ndifficulty\x18\x0f \x01(\x01\x12\x16\n\x0epastMedianTime\x18\x10 \x01(\x04\x12 \n\x18virtualParentHashesCount\x18\x11 \x01(\r\x12\x17\n\x0fvirtualDaaScore\x18\x12 \x01(\x04\"\x81\x01\n\x18GetMetricsRequestMessage\x12\x16\n\x0eprocessMetrics\x18\x01 \x01(\x08\x12\x19\n\x11\x63onnectionMetrics\x18\x02 \x01(\x08\x12\x18\n\x10\x62\x61ndwidthMetrics\x18\x03 \x01(\x08\x12\x18\n\x10\x63onsensusMetrics\x18\x04 \x01(\x08\"\xae\x02\n\x19GetMetricsResponseMessage\x12\x12\n\nserverTime\x18\x01 \x01(\x04\x12\x31\n\x0eprocessMetrics\x18\x0b \x01(\x0b\x32\x19.protowire.ProcessMetrics\x12\x37\n\x11\x63onnectionMetrics\x18\x0c \x01(\x0b\x32\x1c.protowire.ConnectionMetrics\x12\x35\n\x10\x62\x61ndwidthMetrics\x18\r \x01(\x0b\x32\x1b.protowire.BandwidthMetrics\x12\x35\n\x10\x63onsensusMetrics\x18\x0e \x01(\x0b\x32\x1b.protowire.ConsensusMetrics\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1d\n\x1bGetServerInfoRequestMessage\"\xc5\x01\n\x1cGetServerInfoResponseMessage\x12\x15\n\rrpcApiVersion\x18\x01 \x03(\r\x12\x15\n\rserverVersion\x18\x02 \x01(\t\x12\x11\n\tnetworkId\x18\x03 \x01(\t\x12\x14\n\x0chasUtxoIndex\x18\x04 \x01(\x08\x12\x10\n\x08isSynced\x18\x05 \x01(\x08\x12\x17\n\x0fvirtualDaaScore\x18\x06 \x01(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"\x1d\n\x1bGetSyncStatusRequestMessage\"U\n\x1cGetSyncStatusResponseMessage\x12\x10\n\x08isSynced\x18\x01 \x01(\x08\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError\"@\n*GetDaaScoreTimestampEstimateRequestMessage\x12\x12\n\ndaa_scores\x18\x01 \x03(\x04\"f\n+GetDaaScoreTimestampEstimateResponseMessage\x12\x12\n\ntimestamps\x18\x01 \x03(\x04\x12#\n\x05\x65rror\x18\xe8\x07 \x01(\x0b\x32\x13.protowire.RPCError*5\n\x10RpcNotifyCommand\x12\x10\n\x0cNOTIFY_START\x10\x00\x12\x0f\n\x0bNOTIFY_STOP\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._options = None
  _globals['_RPCNOTIFYCOMMAND']._serialized_start=12578
  _globals['_RPCNOTIFYCOMMAND']._serialized_end=12631
  _globals['_RPCERROR']._serialized_start=24
  _globals['_RPCERROR']._serialized_end=51
  _globals['_RPCBLOCK']._serialized_start=54
  _globals['_RPCBLOCK']._serialized_end=209
  _globals['_RPCBLOCKHEADER']._serialized_start=212
  _globals['_RPCBLOCKHEADER']._serialized_end=498
  _globals['_RPCBLOCKLEVELPARENTS']._serialized_start=500
  _globals['_RPCBLOCKLEVELPARENTS']._serialized_end=544
  _globals['_RPCBLOCKVERBOSEDATA']._serialized_start=547
  _globals['_RPCBLOCKVERBOSEDATA']._serialized_end=798
  _globals['_RPCTRANSACTION']._serialized_start=801
  _globals['_RPCTRANSACTION']._serialized_end=1075
  _globals['_RPCTRANSACTIONINPUT']._serialized_start=1078
  _globals['_RPCTRANSACTIONINPUT']._serialized_end=1276
  _globals['_RPCSCRIPTPUBLICKEY']._serialized_start=1278
  _globals['_RPCSCRIPTPUBLICKEY']._serialized_end=1340
  _globals['_RPCTRANSACTIONOUTPUT']._serialized_start=1343
  _globals['_RPCTRANSACTIONOUTPUT']._serialized_end=1502
  _globals['_RPCOUTPOINT']._serialized_start=1504
  _globals['_RPCOUTPOINT']._serialized_end=1555
  _globals['_RPCUTXOENTRY']._serialized_start=1558
  _globals['_RPCUTXOENTRY']._serialized_end=1687
  _globals['_RPCTRANSACTIONVERBOSEDATA']._serialized_start=1689
  _globals['_RPCTRANSACTIONVERBOSEDATA']._serialized_end=1805
  _globals['_RPCTRANSACTIONINPUTVERBOSEDATA']._serialized_start=1807
  _globals['_RPCTRANSACTIONINPUTVERBOSEDATA']._serialized_end=1839
  _globals['_RPCTRANSACTIONOUTPUTVERBOSEDATA']._serialized_start=1841
  _globals['_RPCTRANSACTIONOUTPUTVERBOSEDATA']._serialized_end=1935
  _globals['_GETCURRENTNETWORKREQUESTMESSAGE']._serialized_start=1937
  _globals['_GETCURRENTNETWORKREQUESTMESSAGE']._serialized_end=1970
  _globals['_GETCURRENTNETWORKRESPONSEMESSAGE']._serialized_start=1972
  _globals['_GETCURRENTNETWORKRESPONSEMESSAGE']._serialized_end=2067
  _globals['_SUBMITBLOCKREQUESTMESSAGE']._serialized_start=2069
  _globals['_SUBMITBLOCKREQUESTMESSAGE']._serialized_end=2159
  _globals['_SUBMITBLOCKRESPONSEMESSAGE']._serialized_start=2162
  _globals['_SUBMITBLOCKRESPONSEMESSAGE']._serialized_end=2361
  _globals['_SUBMITBLOCKRESPONSEMESSAGE_REJECTREASON']._serialized_start=2303
  _globals['_SUBMITBLOCKRESPONSEMESSAGE_REJECTREASON']._serialized_end=2361
  _globals['_GETBLOCKTEMPLATEREQUESTMESSAGE']._serialized_start=2363
  _globals['_GETBLOCKTEMPLATEREQUESTMESSAGE']._serialized_end=2434
  _globals['_GETBLOCKTEMPLATERESPONSEMESSAGE']._serialized_start=2436
  _globals['_GETBLOCKTEMPLATERESPONSEMESSAGE']._serialized_end=2560
  _globals['_NOTIFYBLOCKADDEDREQUESTMESSAGE']._serialized_start=2562
  _globals['_NOTIFYBLOCKADDEDREQUESTMESSAGE']._serialized_end=2640
  _globals['_NOTIFYBLOCKADDEDRESPONSEMESSAGE']._serialized_start=2642
  _globals['_NOTIFYBLOCKADDEDRESPONSEMESSAGE']._serialized_end=2712
  _globals['_BLOCKADDEDNOTIFICATIONMESSAGE']._serialized_start=2714
  _globals['_BLOCKADDEDNOTIFICATIONMESSAGE']._serialized_end=2781
  _globals['_GETPEERADDRESSESREQUESTMESSAGE']._serialized_start=2783
  _globals['_GETPEERADDRESSESREQUESTMESSAGE']._serialized_end=2815
  _globals['_GETPEERADDRESSESRESPONSEMESSAGE']._serialized_start=2818
  _globals['_GETPEERADDRESSESRESPONSEMESSAGE']._serialized_end=3028
  _globals['_GETPEERADDRESSESKNOWNADDRESSMESSAGE']._serialized_start=3030
  _globals['_GETPEERADDRESSESKNOWNADDRESSMESSAGE']._serialized_end=3081
  _globals['_GETSINKREQUESTMESSAGE']._serialized_start=3083
  _globals['_GETSINKREQUESTMESSAGE']._serialized_end=3106
  _globals['_GETSINKRESPONSEMESSAGE']._serialized_start=3108
  _globals['_GETSINKRESPONSEMESSAGE']._serialized_end=3183
  _globals['_GETMEMPOOLENTRYREQUESTMESSAGE']._serialized_start=3185
  _globals['_GETMEMPOOLENTRYREQUESTMESSAGE']._serialized_end=3288
  _globals['_GETMEMPOOLENTRYRESPONSEMESSAGE']._serialized_start=3290
  _globals['_GETMEMPOOLENTRYRESPONSEMESSAGE']._serialized_end=3402
  _globals['_GETMEMPOOLENTRIESREQUESTMESSAGE']._serialized_start=3404
  _globals['_GETMEMPOOLENTRIESREQUESTMESSAGE']._serialized_end=3495
  _globals['_GETMEMPOOLENTRIESRESPONSEMESSAGE']._serialized_start=3497
  _globals['_GETMEMPOOLENTRIESRESPONSEMESSAGE']._serialized_end=3613
  _globals['_RPCMEMPOOLENTRY']._serialized_start=3615
  _globals['_RPCMEMPOOLENTRY']._serialized_end=3711
  _globals['_GETCONNECTEDPEERINFOREQUESTMESSAGE']._serialized_start=3713
  _globals['_GETCONNECTEDPEERINFOREQUESTMESSAGE']._serialized_end=3749
  _globals['_GETCONNECTEDPEERINFORESPONSEMESSAGE']._serialized_start=3752
  _globals['_GETCONNECTEDPEERINFORESPONSEMESSAGE']._serialized_end=3881
  _globals['_GETCONNECTEDPEERINFOMESSAGE']._serialized_start=3884
  _globals['_GETCONNECTEDPEERINFOMESSAGE']._serialized_end=4104
  _globals['_ADDPEERREQUESTMESSAGE']._serialized_start=4106
  _globals['_ADDPEERREQUESTMESSAGE']._serialized_end=4167
  _globals['_ADDPEERRESPONSEMESSAGE']._serialized_start=4169
  _globals['_ADDPEERRESPONSEMESSAGE']._serialized_end=4230
  _globals['_SUBMITTRANSACTIONREQUESTMESSAGE']._serialized_start=4232
  _globals['_SUBMITTRANSACTIONREQUESTMESSAGE']._serialized_end=4334
  _globals['_SUBMITTRANSACTIONRESPONSEMESSAGE']._serialized_start=4336
  _globals['_SUBMITTRANSACTIONRESPONSEMESSAGE']._serialized_end=4430
  _globals['_NOTIFYVIRTUALCHAINCHANGEDREQUESTMESSAGE']._serialized_start=4432
  _globals['_NOTIFYVIRTUALCHAINCHANGEDREQUESTMESSAGE']._serialized_end=4558
  _globals['_NOTIFYVIRTUALCHAINCHANGEDRESPONSEMESSAGE']._serialized_start=4560
  _globals['_NOTIFYVIRTUALCHAINCHANGEDRESPONSEMESSAGE']._serialized_end=4639
  _globals['_VIRTUALCHAINCHANGEDNOTIFICATIONMESSAGE']._serialized_start=4642
  _globals['_VIRTUALCHAINCHANGEDNOTIFICATIONMESSAGE']._serialized_end=4816
  _globals['_GETBLOCKREQUESTMESSAGE']._serialized_start=4818
  _globals['_GETBLOCKREQUESTMESSAGE']._serialized_end=4885
  _globals['_GETBLOCKRESPONSEMESSAGE']._serialized_start=4887
  _globals['_GETBLOCKRESPONSEMESSAGE']._serialized_end=4985
  _globals['_GETSUBNETWORKREQUESTMESSAGE']._serialized_start=4987
  _globals['_GETSUBNETWORKREQUESTMESSAGE']._serialized_end=5038
  _globals['_GETSUBNETWORKRESPONSEMESSAGE']._serialized_start=5040
  _globals['_GETSUBNETWORKRESPONSEMESSAGE']._serialized_end=5125
  _globals['_GETVIRTUALCHAINFROMBLOCKREQUESTMESSAGE']._serialized_start=5127
  _globals['_GETVIRTUALCHAINFROMBLOCKREQUESTMESSAGE']._serialized_end=5225
  _globals['_RPCACCEPTEDTRANSACTIONIDS']._serialized_start=5227
  _globals['_RPCACCEPTEDTRANSACTIONIDS']._serialized_end=5314
  _globals['_GETVIRTUALCHAINFROMBLOCKRESPONSEMESSAGE']._serialized_start=5317
  _globals['_GETVIRTUALCHAINFROMBLOCKRESPONSEMESSAGE']._serialized_end=5529
  _globals['_GETBLOCKSREQUESTMESSAGE']._serialized_start=5531
  _globals['_GETBLOCKSREQUESTMESSAGE']._serialized_end=5625
  _globals['_GETBLOCKSRESPONSEMESSAGE']._serialized_start=5627
  _globals['_GETBLOCKSRESPONSEMESSAGE']._serialized_end=5748
  _globals['_GETBLOCKCOUNTREQUESTMESSAGE']._serialized_start=5750
  _globals['_GETBLOCKCOUNTREQUESTMESSAGE']._serialized_end=5779
  _globals['_GETBLOCKCOUNTRESPONSEMESSAGE']._serialized_start=5781
  _globals['_GETBLOCKCOUNTRESPONSEMESSAGE']._serialized_end=5889
  _globals['_GETBLOCKDAGINFOREQUESTMESSAGE']._serialized_start=5891
  _globals['_GETBLOCKDAGINFOREQUESTMESSAGE']._serialized_end=5922
  _globals['_GETBLOCKDAGINFORESPONSEMESSAGE']._serialized_start=5925
  _globals['_GETBLOCKDAGINFORESPONSEMESSAGE']._serialized_end=6213
  _globals['_RESOLVEFINALITYCONFLICTREQUESTMESSAGE']._serialized_start=6215
  _globals['_RESOLVEFINALITYCONFLICTREQUESTMESSAGE']._serialized_end=6281
  _globals['_RESOLVEFINALITYCONFLICTRESPONSEMESSAGE']._serialized_start=6283
  _globals['_RESOLVEFINALITYCONFLICTRESPONSEMESSAGE']._serialized_end=6360
  _globals['_NOTIFYFINALITYCONFLICTREQUESTMESSAGE']._serialized_start=6362
  _globals['_NOTIFYFINALITYCONFLICTREQUESTMESSAGE']._serialized_end=6446
  _globals['_NOTIFYFINALITYCONFLICTRESPONSEMESSAGE']._serialized_start=6448
  _globals['_NOTIFYFINALITYCONFLICTRESPONSEMESSAGE']._serialized_end=6524
  _globals['_FINALITYCONFLICTNOTIFICATIONMESSAGE']._serialized_start=6526
  _globals['_FINALITYCONFLICTNOTIFICATIONMESSAGE']._serialized_end=6591
  _globals['_FINALITYCONFLICTRESOLVEDNOTIFICATIONMESSAGE']._serialized_start=6593
  _globals['_FINALITYCONFLICTRESOLVEDNOTIFICATIONMESSAGE']._serialized_end=6665
  _globals['_SHUTDOWNREQUESTMESSAGE']._serialized_start=6667
  _globals['_SHUTDOWNREQUESTMESSAGE']._serialized_end=6691
  _globals['_SHUTDOWNRESPONSEMESSAGE']._serialized_start=6693
  _globals['_SHUTDOWNRESPONSEMESSAGE']._serialized_end=6755
  _globals['_GETHEADERSREQUESTMESSAGE']._serialized_start=6757
  _globals['_GETHEADERSREQUESTMESSAGE']._serialized_end=6838
  _globals['_GETHEADERSRESPONSEMESSAGE']._serialized_start=6840
  _globals['_GETHEADERSRESPONSEMESSAGE']._serialized_end=6921
  _globals['_NOTIFYUTXOSCHANGEDREQUESTMESSAGE']._serialized_start=6923
  _globals['_NOTIFYUTXOSCHANGEDREQUESTMESSAGE']._serialized_end=7022
  _globals['_NOTIFYUTXOSCHANGEDRESPONSEMESSAGE']._serialized_start=7024
  _globals['_NOTIFYUTXOSCHANGEDRESPONSEMESSAGE']._serialized_end=7096
  _globals['_UTXOSCHANGEDNOTIFICATIONMESSAGE']._serialized_start=7099
  _globals['_UTXOSCHANGEDNOTIFICATIONMESSAGE']._serialized_end=7238
  _globals['_RPCUTXOSBYADDRESSESENTRY']._serialized_start=7241
  _globals['_RPCUTXOSBYADDRESSESENTRY']._serialized_end=7370
  _globals['_STOPNOTIFYINGUTXOSCHANGEDREQUESTMESSAGE']._serialized_start=7372
  _globals['_STOPNOTIFYINGUTXOSCHANGEDREQUESTMESSAGE']._serialized_end=7432
  _globals['_STOPNOTIFYINGUTXOSCHANGEDRESPONSEMESSAGE']._serialized_start=7434
  _globals['_STOPNOTIFYINGUTXOSCHANGEDRESPONSEMESSAGE']._serialized_end=7513
  _globals['_GETUTXOSBYADDRESSESREQUESTMESSAGE']._serialized_start=7515
  _globals['_GETUTXOSBYADDRESSESREQUESTMESSAGE']._serialized_end=7569
  _globals['_GETUTXOSBYADDRESSESRESPONSEMESSAGE']._serialized_start=7571
  _globals['_GETUTXOSBYADDRESSESRESPONSEMESSAGE']._serialized_end=7698
  _globals['_GETBALANCEBYADDRESSREQUESTMESSAGE']._serialized_start=7700
  _globals['_GETBALANCEBYADDRESSREQUESTMESSAGE']._serialized_end=7752
  _globals['_GETBALANCEBYADDRESSRESPONSEMESSAGE']._serialized_start=7754
  _globals['_GETBALANCEBYADDRESSRESPONSEMESSAGE']._serialized_end=7844
  _globals['_GETBALANCESBYADDRESSESREQUESTMESSAGE']._serialized_start=7846
  _globals['_GETBALANCESBYADDRESSESREQUESTMESSAGE']._serialized_end=7903
  _globals['_RPCBALANCESBYADDRESSESENTRY']._serialized_start=7905
  _globals['_RPCBALANCESBYADDRESSESENTRY']._serialized_end=8005
  _globals['_GETBALANCESBYADDRESSESRESPONSEMESSAGE']._serialized_start=8008
  _globals['_GETBALANCESBYADDRESSESRESPONSEMESSAGE']._serialized_end=8141
  _globals['_GETSINKBLUESCOREREQUESTMESSAGE']._serialized_start=8143
  _globals['_GETSINKBLUESCOREREQUESTMESSAGE']._serialized_end=8175
  _globals['_GETSINKBLUESCORERESPONSEMESSAGE']._serialized_start=8177
  _globals['_GETSINKBLUESCORERESPONSEMESSAGE']._serialized_end=8266
  _globals['_NOTIFYSINKBLUESCORECHANGEDREQUESTMESSAGE']._serialized_start=8268
  _globals['_NOTIFYSINKBLUESCORECHANGEDREQUESTMESSAGE']._serialized_end=8356
  _globals['_NOTIFYSINKBLUESCORECHANGEDRESPONSEMESSAGE']._serialized_start=8358
  _globals['_NOTIFYSINKBLUESCORECHANGEDRESPONSEMESSAGE']._serialized_end=8438
  _globals['_SINKBLUESCORECHANGEDNOTIFICATIONMESSAGE']._serialized_start=8440
  _globals['_SINKBLUESCORECHANGEDNOTIFICATIONMESSAGE']._serialized_end=8504
  _globals['_NOTIFYVIRTUALDAASCORECHANGEDREQUESTMESSAGE']._serialized_start=8506
  _globals['_NOTIFYVIRTUALDAASCORECHANGEDREQUESTMESSAGE']._serialized_end=8596
  _globals['_NOTIFYVIRTUALDAASCORECHANGEDRESPONSEMESSAGE']._serialized_start=8598
  _globals['_NOTIFYVIRTUALDAASCORECHANGEDRESPONSEMESSAGE']._serialized_end=8680
  _globals['_VIRTUALDAASCORECHANGEDNOTIFICATIONMESSAGE']._serialized_start=8682
  _globals['_VIRTUALDAASCORECHANGEDNOTIFICATIONMESSAGE']._serialized_end=8750
  _globals['_NOTIFYPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE']._serialized_start=8752
  _globals['_NOTIFYPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE']._serialized_end=8847
  _globals['_NOTIFYPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE']._serialized_start=8849
  _globals['_NOTIFYPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE']._serialized_end=8936
  _globals['_PRUNINGPOINTUTXOSETOVERRIDENOTIFICATIONMESSAGE']._serialized_start=8938
  _globals['_PRUNINGPOINTUTXOSETOVERRIDENOTIFICATIONMESSAGE']._serialized_end=8986
  _globals['_STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE']._serialized_start=8988
  _globals['_STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDEREQUESTMESSAGE']._serialized_end=9044
  _globals['_STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE']._serialized_start=9046
  _globals['_STOPNOTIFYINGPRUNINGPOINTUTXOSETOVERRIDERESPONSEMESSAGE']._serialized_end=9140
  _globals['_BANREQUESTMESSAGE']._serialized_start=9142
  _globals['_BANREQUESTMESSAGE']._serialized_end=9173
  _globals['_BANRESPONSEMESSAGE']._serialized_start=9175
  _globals['_BANRESPONSEMESSAGE']._serialized_end=9232
  _globals['_UNBANREQUESTMESSAGE']._serialized_start=9234
  _globals['_UNBANREQUESTMESSAGE']._serialized_end=9267
  _globals['_UNBANRESPONSEMESSAGE']._serialized_start=9269
  _globals['_UNBANRESPONSEMESSAGE']._serialized_end=9328
  _globals['_GETINFOREQUESTMESSAGE']._serialized_start=9330
  _globals['_GETINFOREQUESTMESSAGE']._serialized_end=9353
  _globals['_GETINFORESPONSEMESSAGE']._serialized_start=9356
  _globals['_GETINFORESPONSEMESSAGE']._serialized_end=9565
  _globals['_ESTIMATENETWORKHASHESPERSECONDREQUESTMESSAGE']._serialized_start=9567
  _globals['_ESTIMATENETWORKHASHESPERSECONDREQUESTMESSAGE']._serialized_end=9652
  _globals['_ESTIMATENETWORKHASHESPERSECONDRESPONSEMESSAGE']._serialized_start=9654
  _globals['_ESTIMATENETWORKHASHESPERSECONDRESPONSEMESSAGE']._serialized_end=9770
  _globals['_NOTIFYNEWBLOCKTEMPLATEREQUESTMESSAGE']._serialized_start=9772
  _globals['_NOTIFYNEWBLOCKTEMPLATEREQUESTMESSAGE']._serialized_end=9856
  _globals['_NOTIFYNEWBLOCKTEMPLATERESPONSEMESSAGE']._serialized_start=9858
  _globals['_NOTIFYNEWBLOCKTEMPLATERESPONSEMESSAGE']._serialized_end=9934
  _globals['_NEWBLOCKTEMPLATENOTIFICATIONMESSAGE']._serialized_start=9936
  _globals['_NEWBLOCKTEMPLATENOTIFICATIONMESSAGE']._serialized_end=9973
  _globals['_RPCMEMPOOLENTRYBYADDRESS']._serialized_start=9976
  _globals['_RPCMEMPOOLENTRYBYADDRESS']._serialized_end=10111
  _globals['_GETMEMPOOLENTRIESBYADDRESSESREQUESTMESSAGE']._serialized_start=10113
  _globals['_GETMEMPOOLENTRIESBYADDRESSESREQUESTMESSAGE']._serialized_end=10234
  _globals['_GETMEMPOOLENTRIESBYADDRESSESRESPONSEMESSAGE']._serialized_start=10237
  _globals['_GETMEMPOOLENTRIESBYADDRESSESRESPONSEMESSAGE']._serialized_end=10373
  _globals['_GETCOINSUPPLYREQUESTMESSAGE']._serialized_start=10375
  _globals['_GETCOINSUPPLYREQUESTMESSAGE']._serialized_end=10404
  _globals['_GETCOINSUPPLYRESPONSEMESSAGE']._serialized_start=10406
  _globals['_GETCOINSUPPLYRESPONSEMESSAGE']._serialized_end=10517
  _globals['_PINGREQUESTMESSAGE']._serialized_start=10519
  _globals['_PINGREQUESTMESSAGE']._serialized_end=10539
  _globals['_PINGRESPONSEMESSAGE']._serialized_start=10541
  _globals['_PINGRESPONSEMESSAGE']._serialized_end=10599
  _globals['_PROCESSMETRICS']._serialized_start=10602
  _globals['_PROCESSMETRICS']._serialized_end=10824
  _globals['_CONNECTIONMETRICS']._serialized_start=10827
  _globals['_CONNECTIONMETRICS']._serialized_end=11054
  _globals['_BANDWIDTHMETRICS']._serialized_start=11057
  _globals['_BANDWIDTHMETRICS']._serialized_end=11259
  _globals['_CONSENSUSMETRICS']._serialized_start=11262
  _globals['_CONSENSUSMETRICS']._serialized_end=11620
  _globals['_GETMETRICSREQUESTMESSAGE']._serialized_start=11623
  _globals['_GETMETRICSREQUESTMESSAGE']._serialized_end=11752
  _globals['_GETMETRICSRESPONSEMESSAGE']._serialized_start=11755
  _globals['_GETMETRICSRESPONSEMESSAGE']._serialized_end=12057
  _globals['_GETSERVERINFOREQUESTMESSAGE']._serialized_start=12059
  _globals['_GETSERVERINFOREQUESTMESSAGE']._serialized_end=12088
  _globals['_GETSERVERINFORESPONSEMESSAGE']._serialized_start=12091
  _globals['_GETSERVERINFORESPONSEMESSAGE']._serialized_end=12288
  _globals['_GETSYNCSTATUSREQUESTMESSAGE']._serialized_start=12290
  _globals['_GETSYNCSTATUSREQUESTMESSAGE']._serialized_end=12319
  _globals['_GETSYNCSTATUSRESPONSEMESSAGE']._serialized_start=12321
  _globals['_GETSYNCSTATUSRESPONSEMESSAGE']._serialized_end=12406
  _globals['_GETDAASCORETIMESTAMPESTIMATEREQUESTMESSAGE']._serialized_start=12408
  _globals['_GETDAASCORETIMESTAMPESTIMATEREQUESTMESSAGE']._serialized_end=12472
  _globals['_GETDAASCORETIMESTAMPESTIMATERESPONSEMESSAGE']._serialized_start=12474
  _globals['_GETDAASCORETIMESTAMPESTIMATERESPONSEMESSAGE']._serialized_end=12576
# @@protoc_insertion_point(module_scope)
